==> aisleriot-3.16.2.tgz: lib/aisleriot/guile/2.0/first-law.go <==
GOOF----BE-4-2.0  %    ] K 4   h      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
g  api	
 	 	
g  initialize-playing-area	g  set-ace-low	g  make-standard-deck	g  shuffle-deck	g  add-normal-slot	g  DECK	g  add-blank-slot	g  give-status-message	g  new-game	g  set-statusbar-message	g  get-stock-no-string	g  
string-append	g  _	f  Stock left:	f   	g  number->string	g  length	g  	get-cards	g  button-pressed	 g  empty-slot?	!g  	get-value	"g  get-top-card	#g  release-move-off?	$g  
no-more-left?	%g  button-released	&g  remove-card	'g  
add-to-score!	(g  	move-off?	)g  	add-card!	*g  
move-left?	+g  deal-cards-face-up	,			 	-g  	flip-deck	.g  button-clicked	/g  button-double-clicked	0g  game-won	1g  game-continuable	2f  Deal another round	3g  	dealable?	4f  Remove the aces	5f  Remove the twos	6f  Remove the threes	7f  Remove the fours	8f  Remove the fives	9f  Remove the sixes	:f  Remove the sevens	;f  Remove the eights	<f  Remove the nines	=f  Remove the tens	>f  Remove the jacks	?f  Remove the queens	@f  Remove the kings	Af  I'm not sure	Bg  
removable?	Cg  move-leftable?	Dg  	hint-move	Ef  Return cards to stock	Fg  get-hint	Gg  get-options	Hg  
apply-options	Ig  timeout	Jg  
set-lambdaC 5    h     ] 4	 >  "  G  
 	  h      ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>   "  G  		 C       g  filenamef  
first-law.scm
	
							#			3			C			U			e			h			m			v			y			~		 		 		 		 		 		 		 	!	 	#	 	 
  g  nameg  new-game CR        h      o] 45 6        g    g  filenamef  
first-law.scm
	%
		&			&	 		
  g  nameg  give-status-message CR    h       ] 45444
5556        g  filenamef  
first-law.scm
	(
		)				)			)		
	)	"		*			*	!		*	)		*	!		*			)	 		
  g  nameg  get-stock-no-string CR    h      ]C           g  slot-id
		 g  	card-list		  g  filenamef  
first-law.scm
	,
 			  g  nameg  button-pressed CR !"#  h   `  C] $  "  %45$  "  454455$  	$  C 6C     ;    g  
start-slot
		] g  	card-list		] g  
check-slot			] g  t			< g  t		E	[  g  filenamef  
first-law.scm
	/
		0	
		0			1			1	
	%	2		*	2		,	2		-	3		0	3		8	3		9	2		@	0		E	4	
	E	4		Y	5	2	[	5	
 		]	  g  nameg  release-move-off? C#R !"$      h   H   ] $  C45$  "  44 554455$  C 6          g  slot1
		E g  slot2		E  g  filenamef  
first-law.scm
	8
		9				9			;			;				<		!	<		)	<		*	=		-	=		5	=		6	<		:	9		C	?	!	E	?	 		E	  g  nameg  
no-more-left? C$R   h      ]C           g  
start-slot
		 g  	card-list		 g  end-slot			  g  filenamef  
first-law.scm
	A
 			  g  nameg  button-released C%R !"&'      h     ]45$  C4	5$  C4	5$  C4	5$  C44	55 4455 $  244	55 $  44	55"  "   $  845$  ,4	5$  4	5$  4	5$  6CCCCC             g  b
	A  g  b	a   g  filenamef  
first-law.scm
	D
		E			E			F			E			G		&	E		)	H		3	E		6	J	
	9	J		A	J	
	A	I		D	I	
	G	I		N	I	
	Q	I		V	K	
	Y	K		a	K	
	a	I		o	L	
	r	L		z	L	
	{	I	 	E	 	M	 	E	 	N	 	E	 	O	 	E	 	P	 	E	 	Q	 $	 
  g  nameg  	move-off? C(R !")&*     h   `  ] $  C45$  "  44 554455$  44 55$   6C 6     
    g  slot1
		] g  slot2		]  g  filenamef  
first-law.scm
	S
		T				T			V			V				W		!	W		)	W		*	X		-	X		5	X		6	W		:	T		;	Y		@	Y		H	Y		L	Y			R	Z		[	[		]	[	 		]	  g  nameg  
move-left? C*R +,-(*      h    ]	 
$  4
5$  "  4
5$  	45 "  $  "  4	5$  "  4
	5$  4	5$  "  4
	5$  W4	5$  "  4
	5$  /45$  "  4
5$  	45 "  "  "  "  "  $  C4 5$  C45 $  C 6       g  slot-id
	 g  t	/  g  t	D	\ g  t	g	 g  t   g  t   g  t  g  t  g  filenamef  
first-law.scm
	]
		^		
	^			_			_			`			`	*	!	`		%	_		&	a		/	_		>	b		D	b		R	c		`	b		a	d		g	d		u	e	 	b	 	f	 	f	 	g	 	b	 	h	 	h	 	i	 	b	 	j	 	^	 	k	 	k		l		l		m	 #	  g  nameg  button-clicked C.R      h      w]C       o    g  slot-id
		  g  filenamef  
first-law.scm
	o
 		  g  nameg  button-double-clicked C/R0        h      l] 45 C          d    g  filenamef  
first-law.scm
	r
		s			s	 			
  g  nameg  game-continuable C1R    h   @   ] 4
5$  ,45$   4	5$  4	5$  	6CCCC             g  filenamef  
first-law.scm
	u
		v			v		
	w			v			x		!	v		"	y		,	v		2	z	 		:
  g  nameg  game-won C0R 2       h       ] 4
5$  C
45 C         }    g  filenamef  
first-law.scm
	|
		}			}			~			~			~			~	 		
  g  nameg  	dealable? C3R !"456789:;<=>?@A        h    ]45$  C4	5$  C4	5$  C4	5$  C44	55 4455 $  244	55 $  44	55"  "   $ 
4455$  45" c4455	$  45" F4455	$  45" )4455	$  45" 4455	$  4	5"  4455	$  4
5"  4455	$  45"  4455	$  45"  4455		$  4
5"  {4455	
$  45"  ^4455	$  45"  A4455	$  45"  $4455	
$  45"  45 CC         g  b
	A  g  b	a   g  filenamef  
first-law.scm
 
	 		 		 		 		 		& 		) 		3 		6 	
	9 		A 	
	A 		D 	
	G 		N 	
	Q 		V 	
	Y 		a 	
	a 		o 	
	r 		z 	
	{ 	  	  	  	$  	  	  	  	  	  	  	  	$  	  	  	  	  	  	  	  	$  	  	  	  	  	  	  	  	$  	  	  	  	  	  	 	 	$ 	 	 	 	 	 	! 	$ 	$+ 	. 	2 	3 	7 	9 	> 	A 	$H 	K 	O 	P 	T 	V 	[ 	^ 	$e 	h 	l 	m 	q 	s 	x 	{ 	$ 	 	 	 	 	 	 	 	$ 	 	 	 	 	 	 	 	$ 	 	 	 	 	 	 	 	$ 	 	 	 	 	 	 	 	$ 	 	 	 	 	 		 	
 	 	 	 	
  g  nameg  
removable? CBRC !"D     h   x  H] 	$  C	$   	 64 5$  "  )45$  "  44 554455$  	 6 6         @    g  slot1
		q g  slot2		q  g  filenamef  
first-law.scm
 
	 			 		 			 		 		  	%	" 			# 		- 			3 		= 			C 		F 		N 		O 		R 		Z 		[ 		_ 		h 			o 		q 		 		q	  g  nameg  move-leftable? CCRBC3E       h   H   ]45   $   C4	5  $   C45   $   C
45 C              g  t
		A g  t
		A g  t
	*	A  g  filenamef  
first-law.scm
 
	 		 		 		 		& 		* 		7 		; 		= 		@ 	 		A
  g  nameg  get-hint CFRh      X] C       P    g  filenamef  
first-law.scm
 
 		
  g  nameg  get-options CGR   h      p]C       h    g  options
		  g  filenamef  
first-law.scm
 
 		  g  nameg  
apply-options CHR   h      T] C       L    g  filenamef  
first-law.scm
 
 		
  g  nameg  timeout CIRJiii%i.i/i1i0iFiGiHiIi6              g  filenamef  
first-law.scm		
	
	%
	(
"	,
	/
3	8
	A

k	D
 	S
0	]
	o
W	r
G	u
	|
 
 
 
{ 
 
o 
 
 	
   C6 

==> aisleriot-3.20.2.tgz: lib/aisleriot/guile/2.0/first-law.go <==
GOOF----LE-4-2.0%      ] K 4   h      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
g  api	
 	 	
g  initialize-playing-area	g  set-ace-low	g  make-standard-deck	g  shuffle-deck	g  add-normal-slot	g  DECK	g  add-blank-slot	g  give-status-message	g  new-game	g  set-statusbar-message	g  get-stock-no-string	g  
string-append	g  _	f  Stock left:	f   	g  number->string	g  length	g  	get-cards	g  button-pressed	 g  empty-slot?	!g  	get-value	"g  get-top-card	#g  release-move-off?	$g  
no-more-left?	%g  button-released	&g  remove-card	'g  
add-to-score!	(g  	move-off?	)g  	add-card!	*g  
move-left?	+g  deal-cards-face-up	,			 	-g  	flip-deck	.g  button-clicked	/g  button-double-clicked	0g  game-won	1g  game-continuable	2f  Deal another round	3g  	dealable?	4f  Remove the aces	5f  Remove the twos	6f  Remove the threes	7f  Remove the fours	8f  Remove the fives	9f  Remove the sixes	:f  Remove the sevens	;f  Remove the eights	<f  Remove the nines	=f  Remove the tens	>f  Remove the jacks	?f  Remove the queens	@f  Remove the kings	Af  I'm not sure	Bg  
removable?	Cg  move-leftable?	Dg  	hint-move	Ef  Return cards to stock	Fg  get-hint	Gg  get-options	Hg  
apply-options	Ig  timeout	Jg  
set-lambdaC 5    h     ] 4	 >  "  G  
 	  h      ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>   "  G  		 C       g  filenamef  
first-law.scm
	
							#			3			C			U			e			h			m			v			y			~		 		 		 		 		 		 		 	!	 	#	 	 
  g  nameg  new-game CR        h   o   ] 45 6     g       g  filenamef  
first-law.scm
	%
		&			&	 		
  g  nameg  give-status-message CR    h       ] 45444
5556        g  filenamef  
first-law.scm
	(
		)				)			)		
	)	"		*			*	!		*	)		*	!		*			)	 		
  g  nameg  get-stock-no-string CR    h      ]C           g  slot-id
		 g  	card-list		  g  filenamef  
first-law.scm
	,
 			  g  nameg  button-pressed CR !"#  h`   C  ] $  "  %45$  "  454455$  	$  C 6C   ;      g  
start-slot
		] g  	card-list		] g  
check-slot			] g  t			< g  t		E	[  g  filenamef  
first-law.scm
	/
		0	
		0			1			1	
	%	2		*	2		,	2		-	3		0	3		8	3		9	2		@	0		E	4	
	E	4		Y	5	2	[	5	
 		]	  g  nameg  release-move-off? C#R !"$      hH      ] $  C45$  "  44 554455$  C 6          g  slot1
		E g  slot2		E  g  filenamef  
first-law.scm
	8
		9				9			;			;				<		!	<		)	<		*	=		-	=		5	=		6	<		:	9		C	?	!	E	?	 		E	  g  nameg  
no-more-left? C$R   h      ]C           g  
start-slot
		 g  	card-list		 g  end-slot			  g  filenamef  
first-law.scm
	A
 			  g  nameg  button-released C%R !"&'      h     ]45$  C4	5$  C4	5$  C4	5$  C44	55 4455 $  244	55 $  44	55"  "   $  845$  ,4	5$  4	5$  4	5$  6CCCCC             g  b
	A  g  b	a   g  filenamef  
first-law.scm
	D
		E			E			F			E			G		&	E		)	H		3	E		6	J	
	9	J		A	J	
	A	I		D	I	
	G	I		N	I	
	Q	I		V	K	
	Y	K		a	K	
	a	I		o	L	
	r	L		z	L	
	{	I	 	E	 	M	 	E	 	N	 	E	 	O	 	E	 	P	 	E	 	Q	 $	 
  g  nameg  	move-off? C(R !")&*     h`     ] $  C45$  "  44 554455$  44 55$   6C 6   
      g  slot1
		] g  slot2		]  g  filenamef  
first-law.scm
	S
		T				T			V			V				W		!	W		)	W		*	X		-	X		5	X		6	W		:	T		;	Y		@	Y		H	Y		L	Y			R	Z		[	[		]	[	 		]	  g  nameg  
move-left? C*R +,-(*      h    ]	 
$  4
5$  "  4
5$  	45 "  $  "  4	5$  "  4
	5$  4	5$  "  4
	5$  W4	5$  "  4
	5$  /45$  "  4
5$  	45 "  "  "  "  "  $  C4 5$  C45 $  C 6       g  slot-id
	 g  t	/  g  t	D	\ g  t	g	 g  t   g  t   g  t  g  t  g  filenamef  
first-law.scm
	]
		^		
	^			_			_			`			`	*	!	`		%	_		&	a		/	_		>	b		D	b		R	c		`	b		a	d		g	d		u	e	 	b	 	f	 	f	 	g	 	b	 	h	 	h	 	i	 	b	 	j	 	^	 	k	 	k		l		l		m	 #	  g  nameg  button-clicked C.R      h   w   ]C    o       g  slot-id
		  g  filenamef  
first-law.scm
	o
 		  g  nameg  button-double-clicked C/R0        h   l   ] 45 C       d       g  filenamef  
first-law.scm
	r
		s			s	 			
  g  nameg  game-continuable C1R    h@      ] 4
5$  ,45$   4	5$  4	5$  	6CCCC             g  filenamef  
first-law.scm
	u
		v			v		
	w			v			x		!	v		"	y		,	v		2	z	 		:
  g  nameg  game-won C0R 2       h       ] 4
5$  C
45 C      }       g  filenamef  
first-law.scm
	|
		}			}			~			~			~			~	 		
  g  nameg  	dealable? C3R !"456789:;<=>?@A        h    ]45$  C4	5$  C4	5$  C4	5$  C44	55 4455 $  244	55 $  44	55"  "   $ 
4455$  45" c4455	$  45" F4455	$  45" )4455	$  45" 4455	$  4	5"  4455	$  4
5"  4455	$  45"  4455	$  45"  4455		$  4
5"  {4455	
$  45"  ^4455	$  45"  A4455	$  45"  $4455	
$  45"  45 CC         g  b
	A  g  b	a   g  filenamef  
first-law.scm
 
	 		 		 		 		 		& 		) 		3 		6 	
	9 		A 	
	A 		D 	
	G 		N 	
	Q 		V 	
	Y 		a 	
	a 		o 	
	r 		z 	
	{ 	  	  	  	$  	  	  	  	  	  	  	  	$  	  	  	  	  	  	  	  	$  	  	  	  	  	  	  	  	$  	  	  	  	  	  	 	 	$ 	 	 	 	 	 	! 	$ 	$+ 	. 	2 	3 	7 	9 	> 	A 	$H 	K 	O 	P 	T 	V 	[ 	^ 	$e 	h 	l 	m 	q 	s 	x 	{ 	$ 	 	 	 	 	 	 	 	$ 	 	 	 	 	 	 	 	$ 	 	 	 	 	 	 	 	$ 	 	 	 	 	 	 	 	$ 	 	 	 	 	 		 	
 	 	 	 	
  g  nameg  
removable? CBRC !"D     hx   H  ] 	$  C	$   	 64 5$  "  )45$  "  44 554455$  	 6 6       @      g  slot1
		q g  slot2		q  g  filenamef  
first-law.scm
 
	 			 		 			 		 		  	%	" 			# 		- 			3 		= 			C 		F 		N 		O 		R 		Z 		[ 		_ 		h 			o 		q 		 		q	  g  nameg  move-leftable? CCRBC3E       hH      ]45   $   C4	5  $   C45   $   C
45 C              g  t
		A g  t
		A g  t
	*	A  g  filenamef  
first-law.scm
 
	 		 		 		 		& 		* 		7 		; 		= 		@ 	 		A
  g  nameg  get-hint CFRh   X   ] C    P       g  filenamef  
first-law.scm
 
 		
  g  nameg  get-options CGR   h   p   ]C    h       g  options
		  g  filenamef  
first-law.scm
 
 		  g  nameg  
apply-options CHR   h   T   ] C    L       g  filenamef  
first-law.scm
 
 		
  g  nameg  timeout CIRJiii%i.i/i1i0iFiGiHiIi6              g  filenamef  
first-law.scm		
	
	%
	(
"	,
	/
3	8
	A

k	D
 	S
0	]
	o
W	r
G	u
	|
 
 
 
{ 
 
o 
 
 	
   C6 
